function [sim, centrality] = social_importance_metric (Adj_full, wifi_nodes, entering_node, weight_seq)
% Adj_full is sparse matrix of size (MN_count,MN_count)
% wifi_nodes is sparse matrix of size (1,MN_count)
% entering_node is scalar in range [1, MN_count]
% weight_seq is scalar to chooose`one of the predefined weight vectors

% Create a new sparse matrix 'sub_g' from Adj and wifi_nodes
subg_nodes = find(wifi_nodes);
if isempty(subg_nodes)  % No terminal connected to wifi [unlikely]
    sim = -1; centrality = -1;
    return;
end
subg_nodes = [subg_nodes entering_node];
subg_count = length(subg_nodes);
sub_g = Adj_full(subg_nodes, subg_nodes);

% Now perform all centrality operations on sub_g with refence to entering_node

if nnz(sub_g) == 0  % Sub-graph is totally empty
    sim = -1; centrality = -1;
    return;
end

% Clustering
% cl_coef = clustering_coefficients(sub_g);

% Eigenvector
[v, d] = eig(full(sub_g));
[maxv, maxi] = max(diag(d));
eigc = abs(v(:,maxi));
eigc = eigc(end);
clear v d maxv maxi;

% Betweenness Centrality - Normalize by (n-1)(n-2)/2
bwc = betweenness_centrality(sub_g) / ((subg_count-1) * (subg_count-2)); % * 2 ???
bwc = bwc(end);

% Degree Centrality - Normalize by (n-1)
degc = full(sum(sub_g) / (subg_count-1));
degc = degc(end); % transpose for consistenecy

if degc == 0 % Incoming user is isolated in subg
    sim = -1; centrality = -1;
    return;
end

% mapping by a sigmoid function
centrality_raw = [degc bwc eigc];
tfactor = [15.8230 99.1721 13.4834]; % empirically found
centrality = ( 2 ./ (1 + exp(-tfactor.*centrality_raw)) ) - 1;
% centrality = centrality_raw;

weight_options = [0.3591  0.3357  0.3052 ;   % weight_seq=1, preset weigths
                  1       0       0      ;
                  0       1       1      ;
                  0       0       1      ;
                  0.5     0.5     0      ;
                  0       0.5     0.5    ;
                  0.5     0       0.5    ;
                  1/3     1/3     1/3    ;
                  1       1       1]     ;       % weight_seq=9, no weigths, just addition

weights = weight_options(weight_seq,:);

sim = weights * centrality'; % dot product