function [percent_traffic_difference, mean_wlan_users, mean_social_wlan_users, mean_admission_prob] = topology(sim_thresh, MN_count, weight_seq, speed_kph)

% tvho = 3; % sec
% tvho_error = -1; % 5 percent defaut

% Simulation Time (seconds)
sim_time = 3600;
ts = 0.1; % time step
t = 0 : ts : sim_time - ts;

users_in_wlan = zeros(1, length(t), 'uint16');
users_in_social_wlan = zeros(1, length(t), 'uint16');

MN_count_static = floor(MN_count/5) + round(rand*MN_count/10);
MN_count_mobile = MN_count - MN_count_static;

% Simulaion Area (1000x1000)m
x_max = 1000;            y_max = 1000;
AP_x = 0.3 * x_max;      BS_x = 0.5 * x_max;
AP_y = 0.3 * y_max;      BS_y = 0.5 * y_max;
AP_count = length(AP_x); BS_count = length(BS_x);

% MN_positions: Array of sets (time-index, MN_id, [MN_x, MN_y])
MN_loc = zeros(length(t), MN_count, 2);
% Evenly distribute 'mobile' users in whole simulation area
MN_loc(1, 1:MN_count_mobile, 1) = rand(1, MN_count_mobile) * x_max;
MN_loc(1, 1:MN_count_mobile, 2) = rand(1, MN_count_mobile) * y_max;
% Distribute static users in WLAN coverages
for j = 1 : MN_count_static
    any_AP = 1 + round(rand * (AP_count-1));
    x_near_AP = (rand * 120) - 60 + AP_x(any_AP); % x and y within 60 meter of AP_x and AP_y
    y_near_AP = (rand * 120) - 60 + AP_y(any_AP);
    MN_loc(1, MN_count_mobile+j, :) = [x_near_AP, y_near_AP];
end
clear any_AP x_near_AP y_near_AP

%% gggggggggggggggggggggggggggggggggggggggggggggg Create connectivity graph
disp('Creating connectivity graph');

Adj = spalloc(MN_count, MN_count, round(0.1*(MN_count^2)));

fprintf('Loading OSN dataset...');
load orkut-imc-data.mat orkut_imc_data;
n_nodes = length(orkut_imc_data);
degrees = sum(orkut_imc_data);
fprintf('done!\n');
source_node = ceil(rand*n_nodes); % Select random BFS seed
while degrees(source_node) == 0
    source_node = ceil(rand*n_nodes);
end
% Calling bfs function from MatlabBGL
[distances, disc_times, pred] = bfs(orkut_imc_data, source_node);
[sorted, indices] = sort(disc_times);
offset = find(1 == sorted); % 'sorted' has a series of -1's in the start corresponding to unreachable nodes
discovered = indices(offset : offset + MN_count - 1);
discovered = discovered(randperm(length(discovered)));
disp(['Source node : ', num2str(source_node), ' - BFS Neighbour 5 : ', num2str(discovered(5))]);
Adj = orkut_imc_data(discovered, discovered); % Extracting sub-graph of size (MN_count)x(MN_count)
Adj = double(Adj);  % orkut_imc_data type is logical
fullg_degrees = degrees(discovered);
clear orkut_imc_data n_nodes degrees source_node distances disc_times pred sorted indices offset discovered
% ggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggg

%% Simulating Mobility mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm
disp('Simulating Mobility');

% Theta - Movement Angle (0 to 120 deg)
% Speed [0.5 to 1.5] m/sec
speed = zeros(length(t)+1,MN_count);
theta = 0;% zeros(1,MN_count);
max_speed = 10; % 10 m/s = 36 kph

dist_AP = zeros(length(t), MN_count, AP_count);
for k = 1 : AP_count
    dist_AP(1,:,k) = sqrt( (MN_loc(1,:,1)-AP_x(k)).^2 + (MN_loc(1,:,2)-AP_y(k)).^2 );
end

subset = MN_count_mobile+1 : MN_count;

for j = 1 : MN_count_mobile
    next_MN_loc = squeeze( MN_loc(1,j,:) );
    i = 2;
    while i <= length(t)
        dif_x = next_MN_loc(1) - MN_loc(i-1,j,1);
        dif_y = next_MN_loc(2) - MN_loc(i-1,j,2);        
        
        near_AP = 0;
        if sqrt( dif_x.^2 + dif_y.^2 ) < 5
            for k = 1 : AP_count  % Check if MN is found near to any APs
                if dist_AP(i-1,j,k) <= 60
                    near_AP = 1;
                    break;
                end
            end
            
            if near_AP == 1
                pause = round(pareto_rand(1) * 60) / ts; % Convert minutes to seconds
            else
                pause = 10 + round(rand(1,1)*50/ts);
            end
            new_i = min(i + pause, length(t));            
            MN_loc(i:new_i-1,j,1) = MN_loc(i-1,j,1);
            MN_loc(i:new_i-1,j,2) = MN_loc(i-1,j,2);
            for k = 1 : AP_count
                dist_AP(i:new_i,j,k) = sqrt( (MN_loc(i:new_i,j,1)-AP_x(k)).^2 + (MN_loc(i:new_i,j,2)-AP_y(k)).^2 );
            end
            i = new_i;
            
            next_MN_loc = [rand*x_max, rand*y_max];
            if speed_kph == -1
                speed(i,j) = 0.5 + rand(1,1) * (max_speed-0.5);
            else
                speed(i,j) = speed_kph / 3.6; % convert to m/s
            end
			
            dif_x = next_MN_loc(1) - MN_loc(i-1,j,1);
            dif_y = next_MN_loc(2) - MN_loc(i-1,j,2);
            theta = ang(dif_y, dif_x);            
        else
            speed(i,j) = speed(i-1,j);
        end
        
        MN_loc(i,j,1) = MN_loc(i-1,j,1) + speed(i,j) * cos(theta) * ts;
        MN_loc(i,j,2) = MN_loc(i-1,j,2) + speed(i,j) * sin(theta) * ts;
        for k = 1 : AP_count
            dist_AP(i,j,k) = sqrt( (MN_loc(i,j,1)-AP_x(k)).^2 + (MN_loc(i,j,2)-AP_y(k)).^2 );
        end
        i = i + 1;
    end
end

for j = 1 : MN_count_static
    % speed - already zero
    MN_loc(:,subset(j),1) = MN_loc(1,subset(j),1);
    MN_loc(:,subset(j),2) = MN_loc(1,subset(j),2);
end
dist_AP(:,subset,k) = sqrt( (MN_loc(:,subset,1)-AP_x(k)).^2 + (MN_loc(:,subset,2)-AP_y(k)).^2 );

clear pause next_MN_loc dif_x dif_y theta subset new_i speed;
% mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm

%% WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW Path Loss & Fading
disp('Path Loss & Fading Calculation');

Ptx_BS = 30; % dBm
Ptx_AP = 18; % dBm

dist_BS = zeros(length(t), MN_count, BS_count);

for j = 1 : BS_count
    dist_BS(:,:,k) = sqrt( (MN_loc(:,:,1)-BS_x(k)).^2 + (MN_loc(:,:,2)-BS_y(k)).^2 );    
end

% log-normal random numbers: parameters - mu = 0, signam = 10 dB
% log-normal = exp(mu + nrml*sigma) where nrmal is guassian random array from N(0,1)
lgnrm = lognrnd(0, 10, [length(t), MN_count, BS_count]);

% dimensions of Prx_AP and Prx_BS : [length(t), MN_count, AP/BS_count]
Prx_BS = Ptx_BS - 128.1 - 37.6*log10(dist_BS/1000) + exp(-max_speed/1000) - 5 - 20*log10(lgnrm)/100; % distance in km
clear lgnrm;

Prx_AP = Ptx_AP - 40 - 35*log10(dist_AP) - 20*log10( rand_rice_fading(2, size(dist_AP) ) ); % fading_coefficent = 2

% Compute Mean RSS by (moving average) exponential average filter
Prx_BS_mean = zeros(size(Prx_BS));
Prx_AP_mean = zeros(size(Prx_AP));
avg_order = 8;
b = ones(1, avg_order)./avg_order;
for j = 1 : MN_count
    for k = 1 : BS_count
        y = Prx_BS(:,j,k);
        Prx_BS_mean(:,j,k) = filter(b, 1, y);
    end
    
    for k = 1 : AP_count
        y = Prx_AP(:,j,k);
        Prx_AP_mean(:,j,k) = filter(b, 1, y);
    end
end
clear a b y Prx_BS;

%% IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII Distribution of Calls
disp('Arrival of Calls');
calls_record = zeros(length(t), MN_count, 'uint8');
lambda = 0.2;

mean_calls_num = round(lambda * sim_time);

del_t = round( exprnd(1/lambda, [1, mean_calls_num]) );
duration = exprnd(60, [1, mean_calls_num]); % Call duration - Exponential, mean: 60 sec;

% Fist call starts randomly during time from 2-10 sec
call_start_time = t( round( (2 + rand*8)/ts ) );

exit_main_loop = 0;
for call = 1 : mean_calls_num    
    if call_start_time >= sim_time
        break;
   end
    
    % Select a non-busy mobile node for next call
    while(1)
        % All the nodes might be busy at selected call_start_time
        % Increment call_start_time in that case
        if sum( calls_record(round(call_start_time/ts),:) ) == MN_count
            call_start_time = call_start_time + 1;
        end
        
        if call_start_time >= sim_time
            exit_main_loop = 1;
            break;
        end
        
        % calls_now : calls_record(round(call_start_time/ts),:)
        % non busy mobile node : rand_distr(find(~calls_now))
        
        % Randomly select a non busy mobile node (if any)
        node = round( 1 + rand*(MN_count-1) );
        if calls_record(round(call_start_time/ts),node) ~= 1
            break;
        end
    end
    
    if exit_main_loop
        break;
    end
    
    call_end_time = call_start_time + duration(call);
    if call_end_time > sim_time
        call_end_time = sim_time;
    end
    calls_record( round(call_start_time/ts) : round(call_end_time/ts), node ) = 1;
    
    call_start_time = call_start_time + del_t(call);
end

% plot(t, calls_record(:,45));
clear call_start_time exit_main_loop lambda mean_calls_num del_t duration call_end_time;

% % If assuming all nodes to be active at all times, then
% calls_record(100:length(t), 1:MN_count) = 1;
% IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII

%% Handover Methods %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% 1 - Mean RSS
% 2 - SCVH

%% Define Var's & Placeholders dddddddddddddddddddddddddddddddddddddddddddd

uvho_instants = zeros(2, length(t), MN_count, 'uint8');
dvho_instants = zeros(2, length(t), MN_count, 'uint8');

uvho_count = zeros(1,2); % Total # of UVHOs
dvho_count = zeros(1,2);
whho_count = zeros(1,2); % """""""""" wlan horizontal HOs
chho_count = zeros(1,2); % """""""""" cellular """""""""

% Record of each MN's attachment to POAs for all times using 3 vho techniques
poa_record = zeros(2, length(t), MN_count, 'uint8');

AP_nodes = zeros(2, AP_count, 'uint16'); % No. of nodes attached to each AP
BS_nodes = zeros(2, BS_count, 'uint16');

wlan_thresh = -87;
wlan_out_thresh = wlan_thresh - 1; % rss threshold (dBm)
wlan_in_thresh = wlan_thresh + 1;
wlan_drop_thresh = -95; % dBm
cell_out_thresh = -104;
cell_in_thresh = -106;

% % Find aproximate WLAN radius
% wlan_radius_est = 10^( (Ptx_AP - 40 - mean(20*log10(rand_rice_fading(fading_coef,[1 1000]))) - wlan_drop_thresh) / 35 ); % Subtract 2 meter to account for fading/noise effects?
% % wlan_radius_est = 70;

% fft_length = 16;
dwt_fixed = 0.5 / ts;  % Dwell Timer of fixed duration (seconds)

below_th_timer    = zeros(1, MN_count, 'uint16');
above_th_AP_timer = zeros(MN_count, AP_count, 'uint16');
above_th_AP_id    = zeros(1, MN_count, 'uint8');
above_th_BS_timer = zeros(MN_count, BS_count, 'uint16');
above_th_BS_id    = zeros(1, MN_count, 'uint8');

AP_nodes_list   = zeros(AP_count, MN_count);  % AP_nodes_list(y,z)=1 if z is attached y
% adaptive_thresh = zeros(length(t),MN_count);

%% Conventional Method MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM

disp('Mean RSS Monitoring');

for i = 1 : length(t)    
    for j = 1 : MN_count
	% Decisions for each mobile node j
        
        % Check for a session in progress
        if calls_record(i,j) == 1
           
            if calls_record(i-1,j) == 1
                % A call already established
                poa = poa_record(1,i-1,j);
                poa_record(1,i,j) = poa;
                
                if poa <= AP_count % Current POA is an AP
                    
                    if Prx_AP_mean(i,j,poa) < wlan_out_thresh % Current RSS decresing
                        below_th_timer(j) = below_th_timer(j) + 1;
                        if below_th_timer(j) >= dwt_fixed % Current RSS has kept low for dwell timer period
                            % ho_need = 1;
                            [map, idx] = max( squeeze(Prx_AP_mean(i,j,:)) );
                            if map >= wlan_in_thresh % Found a WLAN AP above thresh
                                if idx == above_th_AP_id(j)
                                    above_th_AP_timer(j,idx) = above_th_AP_timer(j,idx) + 1;
                                    if above_th_AP_timer(j,idx) >= dwt_fixed % New AP is keeping above thresh
                                        % Execute WLAN Horizontal HO
                                        above_th_AP_timer(j,idx) = 0;
                                        poa_record(1,i,j) = idx;
                                        AP_nodes(1,idx) = AP_nodes(1,idx) + 1;
                                        AP_nodes(1,poa) = AP_nodes(1,poa) - 1;
                                        AP_nodes_list(idx,j) = 1;
                                        AP_nodes(1,poa,j) = 0;
                                        whho_count(1) = whho_count(1) + 1;
                                    end
                                else % Another AP found above thresh
                                    above_th_AP_id(j) = idx;
                                    above_th_AP_timer(j,:) = 0;
                                    above_th_AP_timer(j,idx) = 1;
                                end
                                
                            else % No AP is available, Searching for a BS
                                above_th_AP_id(j) = 0;
                                above_th_AP_timer(j,:) = 0;
                                
                                [mbs, idx] = max( squeeze(Prx_BS_mean(i,j,:)) );
                                if mbs >= cell_in_thresh % Found a BS above thresh
                                    % Execute WLAN-Cellular UVHO
                                    above_th_BS_timer(j,idx) = 0;
                                    poa_record(1,i,j) = AP_count + idx;
                                    BS_nodes(1,idx) = BS_nodes(1,idx) + 1;
                                    AP_nodes(1,poa) = AP_nodes(1,poa) - 1;
                                    AP_nodes_list(poa,j) = 0;
                                    uvho_instants(1,i,j) = 1; % Record an upward VHO
                                    uvho_count(1) = uvho_count(1) + 1;
                                end
                            end
                        end
                    else
                        below_th_timer(j) = 0;
                    end
                    
                else % Current POA is a BS
                    poa = poa - AP_count;
                    [map, idx] = max( squeeze(Prx_AP_mean(i,j,:)) );
                    if map >= wlan_in_thresh % Found a new wlan AP above thresh
                        
                        if idx == above_th_AP_id(j)
                            above_th_AP_timer(j,idx) = above_th_AP_timer(j,idx) + 1;                            
                            if above_th_AP_timer(j,idx) >= dwt_fixed % New AP is keeping above thresh                                
                                % Execute cellular to wlan DVHO
                                above_th_AP_timer(j,idx) = 0;
                                poa_record(1,i,j) = idx;
                                AP_nodes(1,idx) = AP_nodes(1,idx) + 1;
                                BS_nodes(1,poa) = BS_nodes(1,poa) - 1;
                                AP_nodes_list(idx,j) = 1;
                                dvho_instants(1,i,j) = 1; % Record a DVHO
                                dvho_count(1) = dvho_count(1) + 1;
                            end
                        else % Another AP found above thresh
                            above_th_AP_id(j) = idx;
                            above_th_AP_timer(j,:) = 0;
                            above_th_AP_timer(j,idx) = 1;
                        end
                        
                    else % No AP available in the range
                        above_th_AP_id(j) = 0;
                        above_th_AP_timer(j,:) = 0;
                        
                        if Prx_BS_mean(i,j,poa) < cell_out_thresh % Current RSS decreasing
                            % ho_need = 1;
                            [mbs, idx] = max( squeeze(Prx_BS_mean(i,j,:)) );
                            if mbs >= cell_in_thresh % Found a BS above thresh
                                if idx == above_th_BS_id(j)
                                    above_th_BS_timer(j,idx) = above_th_BS_timer(j,idx) + 1;
                                    if above_th_BS_timer(j,idx) >= dwt_fixed % New BS is keeping above thresh
                                        % Execute Cellular Horizontal HO
                                        above_th_BS_timer(j,idx) = 0;
                                        poa_record(1,i,j) = AP_count + idx;
                                        BS_nodes(1,idx) = BS_nodes(1,idx) + 1;
                                        BS_nodes(1,poa) = BS_nodes(1,poa) - 1;
                                        chho_count(1) = chho_count(1) + 1;
                                    end
                                else % Another BS found above thresh
                                    above_th_BS_id(j) = idx;
                                    above_th_BS_timer(j,:) = 0;
                                    above_th_BS_timer(j,idx) = 1;
                                end
                            end
                        else % No BS is in range of MN. (Should not happen)
                            above_th_BS_id(j) = 0;
                            above_th_BS_timer(j,:) = 0;
                        end
                    end
                end
				
            else
                % New Call to Start
                [map, idx] = max( squeeze(Prx_AP_mean(i,j,:)) );
                if map >= wlan_in_thresh
                    poa_record(1,i,j) = idx;
                    AP_nodes(1,idx) = AP_nodes(1,idx) + 1;
                    AP_nodes_list(idx,j) = 1;
                else
                    [mbs, idx] = max( squeeze(Prx_BS_mean(i,j,:)) );
                    if mbs >= cell_in_thresh
                        poa_record(1,i,j) = AP_count + idx;
                        BS_nodes(1,idx) = BS_nodes(1,idx) + 1;
                    end
                end
            end
            
        else
            % No session in progress
            % A session has ended just now ? Clear records
            if i > 1 && calls_record(i-1,j) == 1
                poa = poa_record(1,i-1,j);
                below_th_timer(j) = 0;
                if poa <= AP_count
                    AP_nodes(1,poa) = AP_nodes(1,poa)-1;
                    AP_nodes_list(poa,j) = 0;
                    above_th_AP_timer(j,:) = 0;
                    above_th_AP_id(j) = 0;
                else
                    poa = poa - AP_count;
                    BS_nodes(1,poa) = BS_nodes(1,poa) - 1;
                    above_th_BS_timer(j,:) = 0;
                    above_th_BS_id(j) = 0;
                end
            end
        end
        
    end
    users_in_wlan(i) = AP_nodes(1,1);
end
% MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM

%% SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS Social Metric Test
disp('Social Connectivity Test');
 
below_th_timer    = below_th_timer    * 0;
above_th_AP_timer = above_th_AP_timer * 0;
above_th_AP_id    = above_th_AP_id    * 0;
above_th_BS_timer = above_th_BS_timer * 0;
above_th_BS_id    = above_th_BS_id    * 0;
AP_nodes_list     = AP_nodes_list     * 0;

traffic_ratio = 0;
traffic_ratio_count = 0;
mean_admission_prob = 0;
decision_count = 0;
cluster_coef = 0;
MN_avoid_APs = zeros(length(t), MN_count, 'uint8');

for i = 1 : length(t)
    
    if mod(i,10000) == 0
        disp(num2str(i));
    end
    
    for j = 1 : MN_count
	% Decisions for each mobile node j
        
        % Check for a session in progress
        if calls_record(i,j) == 1
           
            if calls_record(i-1,j) == 1
                % A call already established
                poa = poa_record(2,i-1,j);
                poa_record(2,i,j) = poa;
                
                if poa <= AP_count % Current POA is an AP
                    
                    if Prx_AP_mean(i,j,poa) < wlan_out_thresh % Current RSS decresing
                        below_th_timer(j) = below_th_timer(j) + 1;
                        if below_th_timer(j) >= dwt_fixed % Current RSS has kept low for dwell timer period
                            % ho_need = 1;
                            [map, idx] = max( squeeze(Prx_AP_mean(i,j,:)) );
                            if map >= wlan_in_thresh % Found a WLAN AP above thresh
                                if idx == above_th_AP_id(j)
                                    above_th_AP_timer(j,idx) = above_th_AP_timer(j,idx) + 1;
                                    if above_th_AP_timer(j,idx) >= dwt_fixed % New AP is keeping above thresh
                                        % Execute WLAN Horizontal HO
                                        above_th_AP_timer(j,idx) = 0;
                                        poa_record(2,i,j) = idx;
                                        AP_nodes(2,idx) = AP_nodes(2,idx) + 1;
                                        AP_nodes(2,poa) = AP_nodes(2,poa) - 1;
                                        AP_nodes_list(idx,j) = 1;
                                        AP_nodes(2,poa,j) = 0;
                                        whho_count(2) = whho_count(2) + 1;
                                    end
                                else % Another AP found above thresh
                                    above_th_AP_id(j) = idx;
                                    above_th_AP_timer(j,:) = 0;
                                    above_th_AP_timer(j,idx) = 1;
                                end
                                
                            else % No AP is available, Searching for a BS
                                above_th_AP_id(j) = 0;
                                above_th_AP_timer(j,:) = 0;
                                
                                [mbs, idx] = max( squeeze(Prx_BS_mean(i,j,:)) );
                                if mbs >= cell_in_thresh % Found a BS above thresh
                                    % Execute WLAN-Cellular UVHO
                                    above_th_BS_timer(j,idx) = 0;
                                    poa_record(2,i,j) = AP_count + idx;
                                    BS_nodes(2,idx) = BS_nodes(2,idx) + 1;
                                    AP_nodes(2,poa) = AP_nodes(2,poa) - 1;
                                    AP_nodes_list(poa,j) = 0;
                                    uvho_instants(2,i,j) = 1; % Record an upward VHO
                                    uvho_count(2) = uvho_count(2) + 1;
                                end
                            end
                        end
                    else
                        below_th_timer(j) = 0;
                    end
                    
                else % Current POA is a BS
                    poa = poa - AP_count;
                    [map, idx] = max( squeeze(Prx_AP_mean(i,j,:)) );
                    if map >= wlan_in_thresh && idx ~= MN_avoid_APs(i,j) % Found a new wlan AP above thresh, which hasn't been found in last 20 sec
                        
                        if idx == above_th_AP_id(j) && above_th_AP_timer(j,idx) < 5
                            above_th_AP_timer(j,idx) = above_th_AP_timer(j,idx) + 1;
                            if above_th_AP_timer(j,idx) >= dwt_fixed % New AP is keeping above thresh
                                sim = social_importance_metric (Adj, sparse(AP_nodes_list(idx,:)), j, weight_seq);
                                if rand > sim && sim ~= -1
                                    above_th_AP_timer(j,idx) = 0;
                                    poa_record(2,i,j) = idx;
                                    AP_nodes(2,idx) = AP_nodes(2,idx) + 1;
                                    BS_nodes(2,poa) = BS_nodes(2,poa) - 1;
                                    AP_nodes_list(idx,j) = 1;
                                    dvho_instants(2,i,j) = 1; % Record a DVHO
                                    dvho_count(2) = dvho_count(2) + 1;
                                    decision_count = decision_count + 1;
                                    mean_admission_prob = mean_admission_prob + 1;
                                    
                                    cluster_coef = cluster_coef + mean(clustering_coefficients(Adj));
                                else
                                    % str_vals = [str_vals 0];
                                    MN_avoid_APs(i:i+120/ts,j) = idx; % Do not try to enter this WLAN for next 120 sec
                                    decision_count = decision_count + 1;
                                end
                            end
                        else % Another AP found above thresh
                            above_th_AP_id(j) = idx;
                            above_th_AP_timer(j,:) = 0;
                            above_th_AP_timer(j,idx) = 1;
                        end
                        
                    else % No AP available in the range
                        above_th_AP_id(j) = 0;
                        above_th_AP_timer(j,:) = 0;
                        
                        if Prx_BS_mean(i,j,poa) < cell_out_thresh % Current RSS decreasing
                            % ho_need = 1;
                            [mbs, idx] = max( squeeze(Prx_BS_mean(i,j,:)) );
                            if mbs >= cell_in_thresh % Found a BS above thresh
                                if idx == above_th_BS_id(j)
                                    above_th_BS_timer(j,idx) = above_th_BS_timer(j,idx) + 1;
                                    if above_th_BS_timer(j,idx) >= dwt_fixed % New BS is keeping above thresh
                                        % Execute Cellular Horizontal HO
                                        above_th_BS_timer(j,idx) = 0;
                                        poa_record(2,i,j) = AP_count + idx;
                                        BS_nodes(2,idx) = BS_nodes(2,idx) + 1;
                                        BS_nodes(2,poa) = BS_nodes(2,poa) - 1;
                                        chho_count(2) = chho_count(2) + 1;
                                    end
                                else % Another BS found above thresh
                                    above_th_BS_id(j) = idx;
                                    above_th_BS_timer(j,:) = 0;
                                    above_th_BS_timer(j,idx) = 1;
                                end
                            end
                        else % No BS is in range of MN. (Should not happen)
                            above_th_BS_id(j) = 0;
                            above_th_BS_timer(j,:) = 0;
                        end
                    end
                end
				
            else
                % New Call to Start
                [map, idx] = max( squeeze(Prx_AP_mean(i,j,:)) );
                if map >= wlan_in_thresh
                    poa_record(2,i,j) = idx;
                    AP_nodes(2,idx) = AP_nodes(2,idx) + 1;
                    AP_nodes_list(idx,j) = 1;
                else
                    [mbs, idx] = max( squeeze(Prx_BS_mean(i,j,:)) );
                    if mbs >= cell_in_thresh
                        poa_record(2,i,j) = AP_count + idx;
                        BS_nodes(2,idx) = BS_nodes(2,idx) + 1;
                    end
                end
            end
            
        else
            % No session in progress
            % A session has ended just now ? Clear records
            if i > 1 && calls_record(i-1,j) == 1
                poa = poa_record(2,i-1,j);
                below_th_timer(j) = 0;
                if poa <= AP_count
                    AP_nodes(2,poa) = AP_nodes(2,poa)-1;
                    AP_nodes_list(poa,j) = 0;
                    above_th_AP_timer(j,:) = 0;
                    above_th_AP_id(j) = 0;
                else
                    poa = poa - AP_count;
                    BS_nodes(2,poa) = BS_nodes(2,poa) - 1;
                    above_th_BS_timer(j,:) = 0;
                    above_th_BS_id(j) = 0;
                end
            end
        end
        
    end
	
	k = 1;
	while k <= AP_count && mod(i,5/ts) == 0
		[original, reduced] = social_traffic_ratio(Adj, sparse(AP_nodes_list(k,:)), fullg_degrees);
		if original ~= -1 && original ~= 0
			traffic_ratio = traffic_ratio + (reduced / original);
			traffic_ratio_count = traffic_ratio_count + 1;
		end
		k = k + 1;
	end
    users_in_social_wlan(i) = AP_nodes(2,1); % VHO method 2, AP 1
end
clear MN_avoid_APs;
% SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS

%% Social Traffic Ratio (old)
% social_traffic_normal= 0;
% social_traffic_reduced = 0;
% social_traffic_types = [1 1000 50000]; % assume text 100 bytes, photo 100 KB, video 5 MB
% for j = 1 : MN_count
%     i = (1 + round(rand * 9))/ts; % Starting tweet is 1-10 sec period
%     while i < length(t)
%         current_traffic_type = social_traffic_types(randi(3)); % 1-text, 2-photos, 3-video
%         if poa_record(2, i, j) <= AP_count  % j found in WLAN
%             poa = poa_record(2, i, j);
%             friends_list = find(Adj(j,:));
%             friends_in_wlan = 0;
%             for k = 1 : length(friends_list)
%                 if poa_record(2, i, k) == poa
%                    friends_in_wlan = friends_in_wlan + 1; 
%                 end
%             end
%             social_traffic_normal = social_traffic_normal + current_traffic_type * length(friends_list);
%             social_traffic_reduced = social_traffic_reduced + current_traffic_type * (length(friends_list) - friends_in_wlan);
%         end
%         i = i + (300/ts) + round(randi(60/ts)); % Next tweet after a delay of 5-6 min
%     end
% end
% 
% social_data_ratio = social_traffic_reduced / social_traffic_normal;
% prob_adm = sum(padm) / length(padm);

%%
disp(['<><><> Users in WLAN: ', num2str(sum(AP_nodes_list)), ' <><><><><>']);
disp('Iteration Finished');
disp('.....');

percent_traffic_difference = (1 - (traffic_ratio/traffic_ratio_count)) * 100;
mean_wlan_users = mean(users_in_wlan);
mean_social_wlan_users = mean(users_in_social_wlan);

cluster_coef = cluster_coef / mean_admission_prob;
mean_admission_prob = mean_admission_prob / decision_count;

% load clus.mat
% clc = [clc cluster_coef]; psuc = [psuc mean_admission_prob];
% save clus.mat clc psuc


